/*
 * @(#)RiverDisplay.java  26 April 2003
 *
 * RiverDisplay: a class to display view of the river
 */
 
import java.awt.*;
import java.awt.geom.*;
import edu.neu.ccs.gui.*;	// to get BufferedPanel

public class RiverDisplay{
    
	/*-------------------------------------------------------- 
	 Data Definition: 
	 	river  - the river to display
	 	window - the graphics contexts where river is shown
    --------------------------------------------------------*/
    BufferedPanel window;
    
	/*-------------------------------------------------------- 
	 Constructor
    --------------------------------------------------------*/
    public RiverDisplay (BufferedPanel aWindow) {
        this.window  = aWindow;
    }

	/*-------------------------------------------------------- 
	 Methods: 
    --------------------------------------------------------*/
    
    /*--------------------------------------------------------
     Template:
        --- member data ----------------------------
       
        ...this.showCity(City aCity)...
        ...this.showRiver(ARiver    aRiver)...
        ...this.showRiver(Port      aPort)...
        ...this.showRiver(Tributary tRiver)...
        ...this.showRiverFork(City oneCity, City otherCity)
        
    --------------------------------------------------------*/

    /*--------------------------------------------------------
     Display given city on a map in graphics window
     -------------------------------------------------------*/    
    void showCity(City city){
        
        Point location = city.location;
        
        Graphics2D g2 = window.getBufferGraphics();
        Ellipse2D.Double e = 
            new Ellipse2D.Double(location.x - 1,
                                 location.y - 1,
                                 2, 2);
       g2.setPaint(Color.red);
       g2.fill(e);
       
       g2.setFont(new Font("Courier", Font.BOLD, 12));
       g2.drawString(city.name, location.x + 1, location.y + 1);
       
       window.repaint();
       
    }
        
    /*--------------------------------------------------------
     Display the map of the river singleton in graphics window
     -------------------------------------------------------*/    
    void showRiver(ARiver aRiver){
      if (aRiver instanceof Port)  
      	showRiver(((Port)aRiver));
      else
      	showRiver(((Tributary)aRiver));
    }


    /*--------------------------------------------------------
     Display the map of the river singleton in graphics window
     -------------------------------------------------------*/    
    void showRiver(Port aPort){
        
      showCity(aPort.port);
    }


    /*--------------------------------------------------------
     Display the map of the river in graphics window
     -------------------------------------------------------*/    
    void showRiver(Tributary tRiver){
    
        Graphics2D g2 = window.getBufferGraphics();

        /* show the left tributary */
        showRiverFork(tRiver.port, tRiver.leftTributary.port);
        
        /* show the right tributary */
        showRiverFork(tRiver.port, tRiver.rightTributary.port);
        
        /* show this city */
        showCity(tRiver.port);
        
        showRiver(tRiver.leftTributary);
        showRiver(tRiver.rightTributary);

        window.repaint();
    }

    /*-------------------------------------------------------- 
     Helper method to show one fork of the river on a map 
     -------------------------------------------------------*/
    void showRiverFork(City a, City b){
        
        Graphics2D g2 = window.getBufferGraphics();

        Line2D.Double ln = 
            new Line2D.Double(a.location.x,
                              a.location.y,
                              b.location.x,
                              b.location.y);
                              
        g2.setPaint(Color.blue);
        g2.draw(ln);
        
        showCity(a);
        showCity(b);
    }
        
    /*--------------------------------------------------------
     Print member data
     -------------------------------------------------------*/
	public String toString(){
		return("new " + getClass().getName() + "(" + 
					"window" + ")");
	}
    
}
    
